## Bibcite

Command line tool for instantly generating bibtex citations given only
the title of the work. If the title of the work is not unique then the results
optionally be filtered by the author.

## Usage
```bash
pip install bibcite
```

[//]: # (## Usage)

[//]: # (```)

[//]: # (bibcite )

[//]: # (```)

##  Data sources

Given the title of a work, its DOI is found using https://openalex.org/.
Further details of the reference that OpenAlex may be missing are looked up on https://www.crossref.org/.

